@@ -98,10 +98,19 @@ cat(file="latex.run", sep="\n", append = TRUE)
  cat(file="latex.run",paste(sep=" ", "ps2pdf", SOLTNps,"  >", SOLTNpdf), sep="\n", append = TRUE)
 
 ###########   make a key:
+IDfier = paste(sep=" ",  V, exnumber, seqnum, examdate, instructor, course)
 
+  
   keyfile = paste(sep=".", outMAST, "key") 
   cat(file=keyfile , sep="\n", append = FALSE)
-  for(i in 1:length(QTEMP)) { cat(file=keyfile, paste(sep=" ", i, "ORIG:",  QBord[i], "BUBBLE:",  QTEMP[[i]]$numANS, QTEMP[[i]]$a) , sep="\n",append = TRUE) }
+  cat(file=keyfile ,IDfier,  sep="\n", append=TRUE)
+  for(i in 1:length(QTEMP)) {
+     txtout = QTEMP[[i]]$a
+     txtout = substr(txtout, 1, min(nchar(txtout), 50)   )
+    putout  =  paste(sep="\t", i, "ORIG:",  QBord[i], "BUBBLE:",  QTEMP[[i]]$numANS, txtout)
+    cat(file=keyfile, putout  , sep="\n",append = TRUE)
+
+  }
 
   
  ####
